@@ -13,7 +13,11 @@ def service_instances(args):
     """Get service instances"""
     api_client = ApiClient(get_profile(args))
     api_client.get_service_instances(
-        args.limit, args.offset, args.service_id, args.service_instance_id
+        args.limit,
+        args.offset,
+        args.service_id,
+        args.service_instance_id,
+        args.service_instance_name,
     )
 
 
